==> klayout-0.14.tar.gz: klayout-0.14/src/layExceptions.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "layExceptions.h"
#include "layMainWindow.h"

#include "tlException.h"
#include "tlInternational.h"
#include "tlLog.h"

#include "rba.h"
#include "RubyErrorFormImpl.h"

#include <stdexcept>

#include <QtGui/QMessageBox>

void handle_exception (const tl::Exception &ex)
{
  const RubyError *rba_excpt = dynamic_cast <const RubyError *> (&ex);
  if (rba_excpt) {

    if (rba_excpt->line () > 0) {
      tl::error << rba_excpt->sourcefile () << ":" << rba_excpt->line () << ": " 
                << rba_excpt->msg () << tl::translate (" (class ") << rba_excpt->cls () << ")";
    } else {
      tl::error << rba_excpt->msg () << tl::translate (" (class ") << rba_excpt->cls () << ")";
    }

    RubyErrorFormImpl error_dialog (&lay::MainWindow::instance (), "ruby_error_form", rba_excpt);
    error_dialog.exec ();

  } else {
    tl::error << ex.msg (); 
    QMessageBox::critical (&lay::MainWindow::instance (), tl::translate ("Error").c_str (), ex.msg ().c_str ()); 
  }
}

void handle_exception (const std::exception &ex)
{
  tl::error << ex.what (); 
  QMessageBox::critical (&lay::MainWindow::instance (), tl::translate ("Error").c_str (), ex.what ()); 
}

void handle_exception ()
{
  QMessageBox::critical (&lay::MainWindow::instance (), tl::translate ("Error").c_str (), tl::translate ("An unspecific error occured").c_str ()); 
}

==> klayout-0.15.tar.gz: klayout-0.15/src/layExceptions.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "layExceptions.h"
#include "layMainWindow.h"

#include "tlException.h"
#include "tlInternational.h"
#include "tlLog.h"

#include "rba.h"
#include "RubyErrorFormImpl.h"

#include <stdexcept>

#include <QtGui/QMessageBox>

void handle_exception (const tl::Exception &ex)
{
  handle_exception (ex, &lay::MainWindow::instance ());
}

void handle_exception (const tl::Exception &ex, QWidget *w)
{
  const RubyError *rba_excpt = dynamic_cast <const RubyError *> (&ex);
  if (rba_excpt) {

    if (rba_excpt->line () > 0) {
      tl::error << rba_excpt->sourcefile () << ":" << rba_excpt->line () << ": " 
                << rba_excpt->msg () << tl::translate (" (class ") << rba_excpt->cls () << ")";
    } else {
      tl::error << rba_excpt->msg () << tl::translate (" (class ") << rba_excpt->cls () << ")";
    }

    RubyErrorFormImpl error_dialog (w, "ruby_error_form", rba_excpt);
    error_dialog.exec ();

  } else {
    tl::error << ex.msg (); 
    QMessageBox::critical (w, tl::translate ("Error").c_str (), ex.msg ().c_str ()); 
  }
}

void handle_exception (const std::exception &ex)
{
  handle_exception (ex, &lay::MainWindow::instance ());
}

void handle_exception (const std::exception &ex, QWidget *w)
{
  tl::error << ex.what (); 
  QMessageBox::critical (w, tl::translate ("Error").c_str (), ex.what ()); 
}

void handle_exception ()
{
  handle_exception (&lay::MainWindow::instance ());
}

void handle_exception (QWidget *w)
{
  QMessageBox::critical (w, tl::translate ("Error").c_str (), tl::translate ("An unspecific error occured").c_str ()); 
}
